Stan Math Library: stan/math/prim/scal/meta/contains_fvar.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

contains_fvar.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_CONTAINS_FVAR_HPP
2 #define STAN_MATH_PRIM_SCAL_META_CONTAINS_FVAR_HPP
3
4 #include <stan/math/prim/scal/meta/is_fvar.hpp>
5 #include <stan/math/prim/scal/meta/scalar_type.hpp>
6
7 namespace stan {
8
13 template <typename T1,
14 typename T2 = double,
15 typename T3 = double,
16 typename T4 = double,
17 typename T5 = double,
18 typename T6 = double>
19 struct contains_fvar {
20 enum {
21 value = is_fvar<typename scalar_type<T1>::type>::value
22 || is_fvar<typename scalar_type<T2>::type>::value
23 || is_fvar<typename scalar_type<T3>::type>::value
24 || is_fvar<typename scalar_type<T4>::type>::value
25 || is_fvar<typename scalar_type<T5>::type>::value
26 || is_fvar<typename scalar_type<T6>::type>::value
27 };
28 };
29
30 }
31 #endif
32
stan
Definition: log_sum_exp.hpp:8
is_fvar.hpp
stan::is_fvar
Definition: is_fvar.hpp:7
scalar_type.hpp
stan::contains_fvar
Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of...
Definition: contains_fvar.hpp:19
stan::contains_fvar::value
Definition: contains_fvar.hpp:21

[ Stan Home Page ] © 2011–2016, Stan Development Team.